@@ -7,7 +7,7 @@
 #include "util/debug.h"
 
 #include <unistd.h>
-#include <sys/poll.h>
+#include <poll.h>
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <netdb.h>
