@@ -36,10 +36,11 @@ typedef struct FFPackagesResult
     uint32_t pkg;
     uint32_t pkgsrc;
     uint32_t pkgtool;
-    uint32_t qi;
     uint32_t rpm;
-    uint32_t scoop;
+    uint32_t scoopUser;
+    uint32_t scoopGlobal;
     uint32_t snap;
+    uint32_t soar;
     uint32_t sorcery;
     uint32_t winget;
     uint32_t xbps;
