@@ -519,6 +519,31 @@ static inline uint32_t getFlatpakRuntimePackages(FFstrbuf* baseDir)
     return num_elements;
 }
 
+static inline uint32_t getFlatpakAppPackages(FFstrbuf* baseDir)
+{
+    ffStrbufAppendS(baseDir, "app/");
+    FF_AUTO_CLOSE_DIR DIR* dirp = opendir(baseDir->chars);
+    if (dirp == NULL)
+        return 0;
+
+    uint32_t appDirLength = baseDir->length;
+    uint32_t num_elements = 0;
+
+    struct dirent *entry;
+    while ((entry = readdir(dirp)) != NULL)
+    {
+        if(entry->d_type == DT_DIR && entry->d_name[0] != '.')
+        {
+            ffStrbufAppendS(baseDir, entry->d_name);
+            ffStrbufAppendS(baseDir, "/current");
+            if (ffPathExists(baseDir->chars, FF_PATHTYPE_ANY)) // Exclude deleted apps, #1856
+                ++num_elements;
+            ffStrbufSubstrBefore(baseDir, appDirLength);
+        }
+    }
+    return num_elements;
+}
+
 static uint32_t getFlatpakPackages(FFstrbuf* baseDir, const char* dirname)
 {
     uint32_t num_elements = 0;
@@ -527,8 +552,7 @@ static uint32_t getFlatpakPackages(FFstrbuf* baseDir, const char* dirname)
     ffStrbufAppendS(baseDir, "/flatpak/");
     uint32_t flatpakDirLength = baseDir->length;
 
-    ffStrbufAppendS(baseDir, "app");
-    num_elements += ffPackagesGetNumElements(baseDir->chars, true);
+    num_elements += getFlatpakAppPackages(baseDir);
     ffStrbufSubstrBefore(baseDir, flatpakDirLength);
 
     num_elements += getFlatpakRuntimePackages(baseDir);
@@ -554,7 +578,11 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     if (!(options->disabled & FF_PACKAGES_FLAG_PACMAN_BIT)) packageCounts->pacman += getNumElements(baseDir, "/var/lib/pacman/local", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_LPKGBUILD_BIT)) packageCounts->lpkgbuild += getNumElements(baseDir, "/opt/Loc-OS-LPKG/lpkgbuild/remove", false);
     if (!(options->disabled & FF_PACKAGES_FLAG_PKGTOOL_BIT)) packageCounts->pkgtool += getNumElements(baseDir, "/var/log/packages", false);
-    if (!(options->disabled & FF_PACKAGES_FLAG_RPM_BIT)) packageCounts->rpm += getSQLite3Int(baseDir, "/var/lib/rpm/rpmdb.sqlite", "SELECT count(*) FROM Packages", "rpm");
+    if (!(options->disabled & FF_PACKAGES_FLAG_RPM_BIT))
+    {
+        // `Sigmd5` is the only table that doesn't contain the virtual `gpg-pubkey` package
+        packageCounts->rpm += getSQLite3Int(baseDir, "/var/lib/rpm/rpmdb.sqlite", "SELECT count(*) FROM Sigmd5", "rpm");
+    }
     if (!(options->disabled & FF_PACKAGES_FLAG_SNAP_BIT)) packageCounts->snap += getSnap(baseDir);
     if (!(options->disabled & FF_PACKAGES_FLAG_XBPS_BIT)) packageCounts->xbps += getXBPS(baseDir, "/var/db/xbps");
     if (!(options->disabled & FF_PACKAGES_FLAG_BREW_BIT))
@@ -572,7 +600,6 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     }
     if (!(options->disabled & FF_PACKAGES_FLAG_LINGLONG_BIT)) packageCounts->linglong += getNumElements(baseDir, "/var/lib/linglong/repo/refs/heads/main", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_PACSTALL_BIT)) packageCounts->pacstall += getNumElements(baseDir, "/var/lib/pacstall/metadata", false);
-    if (!(options->disabled & FF_PACKAGES_FLAG_QI_BIT)) packageCounts->qi += getNumStrings(baseDir, "/var/qi/installed_packages.list", "\n", "qi");
     if (!(options->disabled & FF_PACKAGES_FLAG_PISI_BIT)) packageCounts->pisi += getNumElements(baseDir, "/var/lib/pisi/package", true);
     if (!(options->disabled & FF_PACKAGES_FLAG_PKGSRC_BIT)) packageCounts->pkgsrc += getNumElements(baseDir, "/usr/pkg/pkgdb", DT_DIR);
 }
@@ -642,33 +669,30 @@ void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
     #endif
 
     ffStrbufSet(&baseDir, &instance.state.platform.homeDir);
+
     if (!(options->disabled & FF_PACKAGES_FLAG_NIX_BIT))
     {
-        // check if ~/.nix-profile exists
-        FF_STRBUF_AUTO_DESTROY profilePath = ffStrbufCreateCopy(&baseDir);
-        ffStrbufAppendS(&profilePath, ".nix-profile");
-        if (ffPathExists(profilePath.chars, FF_PATHTYPE_DIRECTORY))
-        {
-            result->nixUser += getNixPackages(&baseDir, ".nix-profile");
-        }
+        // Count packages from $HOME/.nix-profile
+        result->nixUser += getNixPackages(&baseDir, ".nix-profile");
 
-        // check if $XDG_STATE_HOME/nix/profile exists
-        FF_STRBUF_AUTO_DESTROY stateDir = ffStrbufCreate();
-        const char* stateHome = getenv("XDG_STATE_HOME");
-        if(ffStrSet(stateHome))
+        // Check in $XDG_STATE_HOME/nix/profile
+        FF_STRBUF_AUTO_DESTROY stateHome = ffStrbufCreate();
+        const char* stateHomeEnv = getenv("XDG_STATE_HOME");
+        if (ffStrSet(stateHomeEnv))
         {
-            ffStrbufSetS(&stateDir, stateHome);
-            ffStrbufEnsureEndsWithC(&stateDir, '/');
+            ffStrbufSetS(&stateHome, stateHomeEnv);
+            ffStrbufEnsureEndsWithC(&stateHome, '/');
         }
         else
         {
-            ffStrbufSet(&stateDir, &instance.state.platform.homeDir);
-            ffStrbufAppendS(&stateDir, ".local/state/");
+            ffStrbufSet(&stateHome, &instance.state.platform.homeDir);
+            ffStrbufAppendS(&stateHome, ".local/state/");
         }
+        result->nixUser += getNixPackages(&stateHome, "nix/profile");
 
-        ffStrbufSet(&profilePath, &stateDir);
-        ffStrbufAppendS(&profilePath, "nix/profile");
-        result->nixUser += getNixPackages(&stateDir, "nix/profile");
+        // Check in /etc/profiles/per-user/$USER
+        FF_STRBUF_AUTO_DESTROY userPkgsDir = ffStrbufCreateStatic("/etc/profiles/per-user/");
+        result->nixUser += getNixPackages(&userPkgsDir, instance.state.platform.userName.chars);
     }
 
     if (!(options->disabled & FF_PACKAGES_FLAG_GUIX_BIT))
@@ -682,4 +706,7 @@ void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
 
     if (!(options->disabled & FF_PACKAGES_FLAG_AM_BIT))
         result->amUser = getAMUser();
+
+    if (!(options->disabled & FF_PACKAGES_FLAG_SOAR_BIT))
+        result->soar += getSQLite3Int(&baseDir, ".local/share/soar/db/soar.db", "SELECT COUNT(DISTINCT pkg_id || pkg_name) FROM packages WHERE is_installed = true", "soar");
 }
