@@ -25,7 +25,7 @@ const char* ffDetectSound(FFlist* devices)
     for (int idev = 0; idev < 9; ++idev)
     {
         path[strlen("/dev/audio")] = (char) ('0' + idev);
-        FF_AUTO_CLOSE_FD int fd = open(path, O_RDWR);
+        FF_AUTO_CLOSE_FD int fd = open(path, O_RDWR | O_CLOEXEC);
         if (fd < 0) break;
 
         audio_device_t ad;
