@@ -1,5 +1,6 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/size.h"
 #include "detection/cpucache/cpucache.h"
 #include "modules/cpucache/cpucache.h"
 #include "util/stringUtils.h"
@@ -12,7 +13,7 @@ static void printCPUCacheNormal(const FFCPUCacheResult* result, FFCPUCacheOption
     FF_STRBUF_AUTO_DESTROY key = ffStrbufCreate();
 
     char levelStr[4] = "L";
-    for (uint32_t i = 0; i < sizeof (result->caches) / sizeof (result->caches[0]) && result->caches[i].length > 0; i++)
+    for (uint32_t i = 0; i < ARRAY_SIZE(result->caches) && result->caches[i].length > 0; i++)
     {
         ffStrbufClear(&key);
         levelStr[1] = (char) ('1' + i);
@@ -45,7 +46,7 @@ static void printCPUCacheNormal(const FFCPUCacheResult* result, FFCPUCacheOption
                 ffStrbufAppendS(&buffer, ", ");
             if (src->num > 1)
                 ffStrbufAppendF(&buffer, "%ux", src->num);
-            ffParseSize(src->size, &buffer);
+            ffSizeAppendNum(src->size, &buffer);
             ffStrbufAppendF(&buffer, " (%c)", typeStr);
 
             sum += src->size * src->num;
@@ -59,7 +60,7 @@ static void printCPUCacheNormal(const FFCPUCacheResult* result, FFCPUCacheOption
         else
         {
             FF_STRBUF_AUTO_DESTROY buffer2 = ffStrbufCreate();
-            ffParseSize(sum, &buffer2);
+            ffSizeAppendNum(sum, &buffer2);
             FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]) {
                 FF_FORMAT_ARG(buffer, "result"),
                 FF_FORMAT_ARG(buffer2, "sum"),
@@ -72,14 +73,14 @@ static void printCPUCacheCompact(const FFCPUCacheResult* result, FFCPUCacheOptio
 {
     FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
     uint64_t sum = 0;
-    for (uint32_t i = 0; i < sizeof (result->caches) / sizeof (result->caches[0]) && result->caches[i].length > 0; i++)
+    for (uint32_t i = 0; i < ARRAY_SIZE(result->caches) && result->caches[i].length > 0; i++)
     {
         if (buffer.length)
             ffStrbufAppendS(&buffer, ", ");
         uint32_t value = 0;
         FF_LIST_FOR_EACH(FFCPUCache, src, result->caches[i])
             value += src->size * src->num;
-        ffParseSize(value, &buffer);
+        ffSizeAppendNum(value, &buffer);
         ffStrbufAppendF(&buffer, " (L%u)", i + 1);
         sum += value;
     }
@@ -92,7 +93,7 @@ static void printCPUCacheCompact(const FFCPUCacheResult* result, FFCPUCacheOptio
     else
     {
         FF_STRBUF_AUTO_DESTROY buffer2 = ffStrbufCreate();
-        ffParseSize(sum, &buffer2);
+        ffSizeAppendNum(sum, &buffer2);
         FF_PRINT_FORMAT_CHECKED(FF_CPUCACHE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]) {
             FF_FORMAT_ARG(buffer, "result"),
             FF_FORMAT_ARG(buffer2, "sum"),
@@ -154,7 +155,7 @@ void ffParseCPUCacheJsonObject(FFCPUCacheOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
@@ -199,7 +200,7 @@ void ffGenerateCPUCacheJsonResult(FF_MAYBE_UNUSED FFCPUCacheOptions* options, yy
 
     yyjson_mut_val* caches = yyjson_mut_obj_add_obj(doc, module, "result");
 
-    for (uint32_t i = 0; i < sizeof (result.caches) / sizeof (result.caches[0]) && result.caches[i].length > 0; i++)
+    for (uint32_t i = 0; i < ARRAY_SIZE(result.caches) && result.caches[i].length > 0; i++)
     {
         yyjson_mut_val* level = yyjson_mut_obj_add_arr(doc, caches, &"l1\0l2\0l3\0l4\0"[i * 3]);
         FF_LIST_FOR_EACH(FFCPUCache, src, result.caches[i])
