@@ -27,6 +27,12 @@ void ffPrintCPUUsage(FFCPUUsageOptions* options)
         if (*percent == *percent)
         {
             sumValue += *percent;
+
+            #if WIN32
+            // Windows may return values greater than 100%, cap them to 100%
+            if (*percent > 100) *percent = 100;
+            #endif
+
             if (*percent > maxValue)
             {
                 maxValue = *percent;
@@ -42,6 +48,10 @@ void ffPrintCPUUsage(FFCPUUsageOptions* options)
         ++index;
     }
     double avgValue = sumValue / (double) valueCount;
+    #if WIN32
+    // See above comment
+    if (avgValue > 100) avgValue = 100;
+    #endif
 
     FFPercentageTypeFlags percentType = options->percent.type == 0 ? instance.config.display.percentType : options->percent.type;
 
@@ -138,7 +148,7 @@ void ffParseCPUUsageJsonObject(FFCPUUsageOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
