@@ -1,7 +1,7 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
-#include "common/parsing.h"
 #include "common/percent.h"
+#include "common/size.h"
 #include "common/time.h"
 #include "detection/disk/disk.h"
 #include "modules/disk/disk.h"
@@ -44,10 +44,10 @@ static void printDisk(FFDiskOptions* options, const FFDisk* disk, uint32_t index
     }
 
     FF_STRBUF_AUTO_DESTROY usedPretty = ffStrbufCreate();
-    ffParseSize(disk->bytesUsed, &usedPretty);
+    ffSizeAppendNum(disk->bytesUsed, &usedPretty);
 
     FF_STRBUF_AUTO_DESTROY totalPretty = ffStrbufCreate();
-    ffParseSize(disk->bytesTotal, &totalPretty);
+    ffSizeAppendNum(disk->bytesTotal, &totalPretty);
 
     double bytesPercentage = disk->bytesTotal > 0 ? (double) disk->bytesUsed / (double) disk->bytesTotal * 100.0 : 0;
     FFPercentageTypeFlags percentType = options->percent.type == 0 ? instance.config.display.percentType : options->percent.type;
@@ -125,7 +125,8 @@ static void printDisk(FFDiskOptions* options, const FFDisk* disk, uint32_t index
         bool isHidden = !!(disk->type & FF_DISK_VOLUME_TYPE_HIDDEN_BIT);
         bool isReadOnly = !!(disk->type & FF_DISK_VOLUME_TYPE_READONLY_BIT);
 
-        uint64_t duration = ffTimeGetNow() - disk->createTime;
+        uint64_t now = ffTimeGetNow();
+        uint64_t duration = now - disk->createTime;
         uint32_t milliseconds = (uint32_t) (duration % 1000);
         duration /= 1000;
         uint32_t seconds = (uint32_t) (duration % 60);
@@ -136,6 +137,7 @@ static void printDisk(FFDiskOptions* options, const FFDisk* disk, uint32_t index
         duration /= 24;
         uint32_t days = (uint32_t) duration;
 
+        FFTimeGetAgeResult age = ffTimeGetAge(disk->createTime, now);
         FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]) {
             FF_FORMAT_ARG(usedPretty, "size-used"),
             FF_FORMAT_ARG(totalPretty, "size-total"),
@@ -158,6 +160,9 @@ static void printDisk(FFDiskOptions* options, const FFDisk* disk, uint32_t index
             FF_FORMAT_ARG(milliseconds, "milliseconds"),
             FF_FORMAT_ARG(disk->mountpoint, "mountpoint"),
             FF_FORMAT_ARG(disk->mountFrom, "mount-from"),
+            FF_FORMAT_ARG(age.years, "years"),
+            FF_FORMAT_ARG(age.daysOfYear, "days-of-year"),
+            FF_FORMAT_ARG(age.yearsFraction, "years-fraction"),
         }));
     }
 }
@@ -179,6 +184,12 @@ void ffPrintDisk(FFDiskOptions* options)
             if(__builtin_expect(options->folders.length == 0, 1) && (disk->type & ~options->showTypes))
                 continue;
 
+            if (options->hideFolders.length && ffDiskMatchMountpoint(&options->hideFolders, disk->mountpoint.chars))
+                continue;
+
+            if (options->hideFS.length && ffStrbufMatchSeparated(&disk->filesystem, &options->hideFS, ':'))
+                continue;
+
             printDisk(options, disk, ++index);
         }
     }
@@ -205,6 +216,18 @@ bool ffParseDiskCommandOptions(FFDiskOptions* options, const char* key, const ch
         return true;
     }
 
+    if (ffStrEqualsIgnCase(subKey, "hide-folders"))
+    {
+        ffOptionParseString(key, value, &options->hideFolders);
+        return true;
+    }
+
+    if (ffStrEqualsIgnCase(subKey, "hide-fs"))
+    {
+        ffOptionParseString(key, value, &options->hideFS);
+        return true;
+    }
+
     if (ffStrEqualsIgnCase(subKey, "show-regular"))
     {
         if (ffOptionParseBoolean(value))
@@ -281,7 +304,7 @@ void ffParseDiskJsonObject(FFDiskOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
@@ -293,6 +316,18 @@ void ffParseDiskJsonObject(FFDiskOptions* options, yyjson_val* module)
             continue;
         }
 
+        if (ffStrEqualsIgnCase(key, "hideFolders"))
+        {
+            ffStrbufSetS(&options->hideFolders, yyjson_get_str(val));
+            continue;
+        }
+
+        if (ffStrEqualsIgnCase(key, "hideFS"))
+        {
+            ffStrbufSetS(&options->hideFS, yyjson_get_str(val));
+            continue;
+        }
+
         if (ffStrEqualsIgnCase(key, "showExternal"))
         {
             if (yyjson_get_bool(val))
@@ -382,6 +417,12 @@ void ffGenerateDiskJsonConfig(FFDiskOptions* options, yyjson_mut_doc* doc, yyjso
     if (!ffStrbufEqual(&options->folders, &defaultOptions.folders))
         yyjson_mut_obj_add_strbuf(doc, module, "folders", &options->folders);
 
+    if (!ffStrbufEqual(&options->hideFolders, &defaultOptions.hideFolders))
+        yyjson_mut_obj_add_strbuf(doc, module, "hideFolders", &options->hideFolders);
+
+    if (!ffStrbufEqual(&options->hideFS, &defaultOptions.hideFS))
+        yyjson_mut_obj_add_strbuf(doc, module, "hideFS", &options->hideFS);
+
     if (defaultOptions.calcType != options->calcType)
         yyjson_mut_obj_add_bool(doc, module, "useAvailable", options->calcType == FF_DISK_CALC_TYPE_AVAILABLE);
 
@@ -487,6 +528,9 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Milliseconds after creation", "milliseconds"},
         {"Mount point / drive letter", "mountpoint"},
         {"Mount from (device path)", "mount-from"},
+        {"Years integer after creation", "years"},
+        {"Days of year after creation", "days-of-year"},
+        {"Years fraction after creation", "years-fraction"},
     }))
 };
 
@@ -496,6 +540,12 @@ void ffInitDiskOptions(FFDiskOptions* options)
     ffOptionInitModuleArg(&options->moduleArgs, "");
 
     ffStrbufInit(&options->folders);
+    #if _WIN32 || __APPLE__ || __ANDROID__
+    ffStrbufInit(&options->hideFolders);
+    #else
+    ffStrbufInitStatic(&options->hideFolders, "/efi:/boot:/boot/efi:/boot/firmware");
+    #endif
+    ffStrbufInit(&options->hideFS);
     options->showTypes = FF_DISK_VOLUME_TYPE_REGULAR_BIT | FF_DISK_VOLUME_TYPE_EXTERNAL_BIT | FF_DISK_VOLUME_TYPE_READONLY_BIT;
     options->calcType = FF_DISK_CALC_TYPE_FREE;
     options->percent = (FFPercentageModuleConfig) { 50, 80, 0 };
@@ -504,4 +554,7 @@ void ffInitDiskOptions(FFDiskOptions* options)
 void ffDestroyDiskOptions(FFDiskOptions* options)
 {
     ffOptionDestroyModuleArg(&options->moduleArgs);
+    ffStrbufDestroy(&options->folders);
+    ffStrbufDestroy(&options->hideFolders);
+    ffStrbufDestroy(&options->hideFS);
 }
