@@ -1,6 +1,6 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
-#include "common/parsing.h"
+#include "common/size.h"
 #include "detection/diskio/diskio.h"
 #include "modules/diskio/diskio.h"
 #include "util/stringUtils.h"
@@ -57,22 +57,22 @@ void ffPrintDiskIO(FFDiskIOOptions* options)
         {
             ffPrintLogoAndKey(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY);
 
-            ffParseSize(dev->bytesRead, &buffer);
+            ffSizeAppendNum(dev->bytesRead, &buffer);
             if (!options->detectTotal) ffStrbufAppendS(&buffer, "/s");
             ffStrbufAppendS(&buffer, " (R) - ");
 
-            ffParseSize(dev->bytesWritten, &buffer);
+            ffSizeAppendNum(dev->bytesWritten, &buffer);
             if (!options->detectTotal) ffStrbufAppendS(&buffer, "/s");
             ffStrbufAppendS(&buffer, " (W)");
             ffStrbufPutTo(&buffer, stdout);
         }
         else
         {
+            ffSizeAppendNum(dev->bytesRead, &buffer);
+            if (!options->detectTotal) ffStrbufAppendS(&buffer, "/s");
             ffStrbufClear(&buffer2);
-            ffParseSize(dev->bytesRead, &buffer);
-            if (!options->detectTotal) ffStrbufAppendS(&buffer, "/s");
-            ffParseSize(dev->bytesWritten, &buffer2);
-            if (!options->detectTotal) ffStrbufAppendS(&buffer, "/s");
+            ffSizeAppendNum(dev->bytesWritten, &buffer2);
+            if (!options->detectTotal) ffStrbufAppendS(&buffer2, "/s");
 
             FF_PRINT_FORMAT_CHECKED(key.chars, 0, &options->moduleArgs, FF_PRINT_TYPE_NO_CUSTOM_KEY, ((FFformatarg[]){
                 FF_FORMAT_ARG(buffer, "size-read"),
@@ -130,7 +130,7 @@ void ffParseDiskIOJsonObject(FFDiskIOOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
