@@ -1,8 +1,9 @@
 #include "common/percent.h"
-#include "common/parsing.h"
 #include "common/printing.h"
 #include "common/jsonconfig.h"
 #include "common/temps.h"
+#include "common/size.h"
+#include "common/frequency.h"
 #include "detection/host/host.h"
 #include "detection/gpu/gpu.h"
 #include "modules/gpu/gpu.h"
@@ -42,7 +43,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         if(gpu->frequency > 0)
         {
             ffStrbufAppendS(&output, " @ ");
-            ffParseFrequency(gpu->frequency, &output);
+            ffFreqAppendNum(gpu->frequency, &output);
         }
 
         if(gpu->temperature == gpu->temperature) //FF_GPU_TEMP_UNSET
@@ -59,10 +60,10 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             {
                 if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
                 {
-                    ffParseSize(gpu->dedicated.used, &output);
+                    ffSizeAppendNum(gpu->dedicated.used, &output);
                     ffStrbufAppendS(&output, " / ");
                 }
-                ffParseSize(gpu->dedicated.total, &output);
+                ffSizeAppendNum(gpu->dedicated.total, &output);
             }
             if(gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
             {
@@ -94,8 +95,8 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         FF_STRBUF_AUTO_DESTROY dUsed = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY dPercentNum = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY dPercentBar = ffStrbufCreate();
-        if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.total, &dTotal);
-        if (gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->dedicated.used, &dUsed);
+        if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET) ffSizeAppendNum(gpu->dedicated.total, &dTotal);
+        if (gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET) ffSizeAppendNum(gpu->dedicated.used, &dUsed);
         if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET && gpu->dedicated.used != FF_GPU_VMEM_SIZE_UNSET)
         {
             double percent = (double) gpu->dedicated.used / (double) gpu->dedicated.total * 100.0;
@@ -109,8 +110,8 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         FF_STRBUF_AUTO_DESTROY sUsed = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY sPercentNum = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY sPercentBar = ffStrbufCreate();
-        if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.total, &sTotal);
-        if (gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET) ffParseSize(gpu->shared.used, &sUsed);
+        if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET) ffSizeAppendNum(gpu->shared.total, &sTotal);
+        if (gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET) ffSizeAppendNum(gpu->shared.used, &sUsed);
         if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET && gpu->shared.used != FF_GPU_VMEM_SIZE_UNSET)
         {
             double percent = (double) gpu->shared.used / (double) gpu->shared.total * 100.0;
@@ -121,7 +122,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
         }
 
         FF_STRBUF_AUTO_DESTROY frequency = ffStrbufCreate();
-        ffParseFrequency(gpu->frequency, &frequency);
+        ffFreqAppendNum(gpu->frequency, &frequency);
 
         FF_STRBUF_AUTO_DESTROY coreUsageNum = ffStrbufCreate();
         FF_STRBUF_AUTO_DESTROY coreUsageBar = ffStrbufCreate();
@@ -173,6 +174,9 @@ void ffPrintGPU(FFGPUOptions* options)
 
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
     {
+        if(gpu->type == FF_GPU_TYPE_UNKNOWN && options->hideType == FF_GPU_TYPE_UNKNOWN)
+            continue;
+
         if(gpu->type == FF_GPU_TYPE_INTEGRATED && options->hideType == FF_GPU_TYPE_INTEGRATED)
             continue;
 
@@ -230,7 +234,8 @@ bool ffParseGPUCommandOptions(FFGPUOptions* options, const char* key, const char
     if (ffStrEqualsIgnCase(subKey, "hide-type"))
     {
         options->hideType = (FFGPUType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "none", FF_GPU_TYPE_UNKNOWN },
+            { "none", FF_GPU_TYPE_NONE },
+            { "unknown", FF_GPU_TYPE_UNKNOWN },
             { "integrated", FF_GPU_TYPE_INTEGRATED },
             { "discrete", FF_GPU_TYPE_DISCRETE },
             {},
@@ -251,7 +256,7 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
@@ -288,7 +293,8 @@ void ffParseGPUJsonObject(FFGPUOptions* options, yyjson_val* module)
         {
             int value;
             const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
-                { "none", FF_GPU_TYPE_UNKNOWN },
+                { "none", FF_GPU_TYPE_NONE },
+                { "unknown", FF_GPU_TYPE_UNKNOWN },
                 { "integrated", FF_GPU_TYPE_INTEGRATED },
                 { "discrete", FF_GPU_TYPE_DISCRETE },
                 {},
@@ -345,9 +351,12 @@ void ffGenerateGPUJsonConfig(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
     {
         switch (options->hideType)
         {
-            case FF_GPU_TYPE_UNKNOWN:
+            case FF_GPU_TYPE_NONE:
                 yyjson_mut_obj_add_str(doc, module, "hideType", "none");
                 break;
+            case FF_GPU_TYPE_UNKNOWN:
+                yyjson_mut_obj_add_str(doc, module, "hideType", "unknown");
+                break;
             case FF_GPU_TYPE_INTEGRATED:
                 yyjson_mut_obj_add_str(doc, module, "hideType", "integrated");
                 break;
@@ -497,7 +506,7 @@ void ffInitGPUOptions(FFGPUOptions* options)
         #endif
     ;
     options->temp = false;
-    options->hideType = FF_GPU_TYPE_UNKNOWN;
+    options->hideType = FF_GPU_TYPE_NONE;
     options->tempConfig = (FFColorRangeConfig) { 60, 80 };
     options->percent = (FFPercentageModuleConfig) { 50, 80, 0 };
 }
