@@ -19,12 +19,22 @@ void ffPrintWM(FFWMOptions* options)
     if(options->detectPlugin)
         ffDetectWMPlugin(&pluginName);
 
+    FF_STRBUF_AUTO_DESTROY version = ffStrbufCreate();
+    if (instance.config.general.detectVersion)
+        ffDetectWMVersion(&result->wmProcessName, &version, options);
+
     if(options->moduleArgs.outputFormat.length == 0)
     {
         ffPrintLogoAndKey(FF_WM_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
 
         ffStrbufWriteTo(&result->wmPrettyName, stdout);
 
+        if(version.length > 0)
+        {
+            putchar(' ');
+            ffStrbufWriteTo(&version, stdout);
+        }
+
         if(result->wmProtocolName.length > 0)
         {
             fputs(" (", stdout);
@@ -48,6 +58,7 @@ void ffPrintWM(FFWMOptions* options)
             FF_FORMAT_ARG(result->wmPrettyName, "pretty-name"),
             FF_FORMAT_ARG(result->wmProtocolName, "protocol-name"),
             FF_FORMAT_ARG(pluginName, "plugin-name"),
+            FF_FORMAT_ARG(version, "version"),
         }));
     }
 }
@@ -75,7 +86,7 @@ void ffParseWMJsonObject(FFWMOptions* options, yyjson_val* module)
     yyjson_obj_foreach(module, idx, max, key_, val)
     {
         const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
+        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
             continue;
 
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
@@ -116,11 +127,16 @@ void ffGenerateWMJsonResult(FF_MAYBE_UNUSED FFWMOptions* options, yyjson_mut_doc
     if(options->detectPlugin)
         ffDetectWMPlugin(&pluginName);
 
+    FF_STRBUF_AUTO_DESTROY version = ffStrbufCreate();
+    if (instance.config.general.detectVersion)
+        ffDetectWMVersion(&result->wmProcessName, &version, options);
+
     yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
     yyjson_mut_obj_add_strbuf(doc, obj, "processName", &result->wmProcessName);
     yyjson_mut_obj_add_strbuf(doc, obj, "prettyName", &result->wmPrettyName);
     yyjson_mut_obj_add_strbuf(doc, obj, "protocolName", &result->wmProtocolName);
     yyjson_mut_obj_add_strbuf(doc, obj, "pluginName", &pluginName);
+    yyjson_mut_obj_add_strbuf(doc, obj, "version", &version);
 }
 
 static FFModuleBaseInfo ffModuleInfo = {
@@ -136,6 +152,7 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"WM pretty name", "pretty-name"},
         {"WM protocol name", "protocol-name"},
         {"WM plugin name", "plugin-name"},
+        {"WM version", "version"},
     }))
 };
 
