@@ -78,6 +78,28 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
             options->brightColor = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "binaryPrefix"))
             return "`display.binaryPrefix` has been renamed to `display.size.binaryPrefix`. Sorry for another break change.";
+        else if (ffStrEqualsIgnCase(key, "duration"))
+        {
+            if (!yyjson_is_obj(val))
+                return "display.duration must be an object";
+
+            yyjson_val* abbreviation = yyjson_obj_get(val, "abbreviation");
+            if (abbreviation) options->durationAbbreviation = yyjson_get_bool(abbreviation);
+
+            yyjson_val* spaceBeforeUnit = yyjson_obj_get(val, "spaceBeforeUnit");
+            if (spaceBeforeUnit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(spaceBeforeUnit, &value, (FFKeyValuePair[]) {
+                    { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                    { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                    { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                    {},
+                });
+                if (error) return error;
+                options->durationSpaceBeforeUnit = (FFSpaceBeforeUnitType) value;
+            }
+        }
         else if (ffStrEqualsIgnCase(key, "size"))
         {
             if (!yyjson_is_obj(val))
@@ -119,6 +141,20 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
 
             yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
             if (ndigits) options->sizeNdigits = (uint8_t) yyjson_get_uint(ndigits);
+
+            yyjson_val* spaceBeforeUnit = yyjson_obj_get(val, "spaceBeforeUnit");
+            if (spaceBeforeUnit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(spaceBeforeUnit, &value, (FFKeyValuePair[]) {
+                    { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                    { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                    { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                    {},
+                });
+                if (error) return error;
+                options->sizeSpaceBeforeUnit = (FFSpaceBeforeUnitType) value;
+            }
         }
         else if (ffStrEqualsIgnCase(key, "temp"))
         {
@@ -162,6 +198,20 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 yyjson_val* red = yyjson_obj_get(color, "red");
                 if (red) ffOptionParseColor(yyjson_get_str(red), &options->tempColorRed);
             }
+
+            yyjson_val* spaceBeforeUnit = yyjson_obj_get(val, "spaceBeforeUnit");
+            if (spaceBeforeUnit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(spaceBeforeUnit, &value, (FFKeyValuePair[]) {
+                    { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                    { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                    { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                    {},
+                });
+                if (error) return error;
+                options->tempSpaceBeforeUnit = (FFSpaceBeforeUnitType) value;
+            }
         }
         else if (ffStrEqualsIgnCase(key, "percent"))
         {
@@ -193,6 +243,23 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 yyjson_val* red = yyjson_obj_get(color, "red");
                 if (red) ffOptionParseColor(yyjson_get_str(red), &options->percentColorRed);
             }
+
+            yyjson_val* spaceBeforeUnit = yyjson_obj_get(val, "spaceBeforeUnit");
+            if (spaceBeforeUnit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(spaceBeforeUnit, &value, (FFKeyValuePair[]) {
+                    { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                    { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                    { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                    {},
+                });
+                if (error) return error;
+                options->percentSpaceBeforeUnit = (FFSpaceBeforeUnitType) value;
+            }
+
+            yyjson_val* width = yyjson_obj_get(val, "width");
+            if (width) options->percentWidth = (uint8_t) yyjson_get_uint(width);
         }
         else if (ffStrEqualsIgnCase(key, "bar"))
         {
@@ -221,6 +288,23 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
             else
                 return "display.bar must be an object";
         }
+        else if (ffStrEqualsIgnCase(key, "fraction"))
+        {
+            if (yyjson_is_obj(val))
+            {
+                yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
+                if (ndigits)
+                {
+                    if (yyjson_is_null(ndigits))
+                        options->fractionNdigits = -1;
+                    else if (!yyjson_is_int(ndigits))
+                        return "display.fraction.ndigits must be an integer";
+                    options->fractionNdigits = (int8_t) yyjson_get_int(ndigits);
+                }
+            }
+            else
+                return "display.fraction must be an object";
+        }
         else if (ffStrEqualsIgnCase(key, "noBuffer"))
             options->noBuffer = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "keyWidth"))
@@ -271,6 +355,20 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
 
             yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
             if (ndigits) options->freqNdigits = (int8_t) yyjson_get_int(ndigits);
+
+            yyjson_val* spaceBeforeUnit = yyjson_obj_get(val, "spaceBeforeUnit");
+            if (spaceBeforeUnit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(spaceBeforeUnit, &value, (FFKeyValuePair[]) {
+                    { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                    { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                    { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                    {},
+                });
+                if (error) return error;
+                options->freqSpaceBeforeUnit = (FFSpaceBeforeUnitType) value;
+            }
         }
         else
             return "Unknown display property";
@@ -317,6 +415,10 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         options->pipe = ffOptionParseBoolean(value);
     else if(ffStrEqualsIgnCase(key, "--show-errors"))
         options->showErrors = ffOptionParseBoolean(value);
+    #ifndef NDEBUG
+    else if(ffStrEqualsIgnCase(key, "--debug"))
+        options->debugMode = ffOptionParseBoolean(value);
+    #endif
     else if(ffStrEqualsIgnCase(key, "--disable-linewrap"))
         options->disableLinewrap = ffOptionParseBoolean(value);
     else if(ffStrEqualsIgnCase(key, "--hide-cursor"))
@@ -382,6 +484,23 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         fprintf(stderr, "--binary-prefix has been renamed to --size-binary-prefix\n");
         exit(477);
     }
+    else if(ffStrStartsWithIgnCase(key, "--duration-"))
+    {
+        const char* subkey = key + strlen("--duration-");
+        if(ffStrEqualsIgnCase(subkey, "abbreviation"))
+            options->durationAbbreviation = ffOptionParseBoolean(value);
+        else if(ffStrEqualsIgnCase(subkey, "space-before-unit"))
+        {
+            options->durationSpaceBeforeUnit = (FFSpaceBeforeUnitType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                {},
+            });
+        }
+        else
+            return false;
+    }
     else if(ffStrStartsWithIgnCase(key, "--size-"))
     {
         const char* subkey = key + strlen("--size-");
@@ -411,6 +530,15 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
                 {}
             });
         }
+        else if(ffStrEqualsIgnCase(subkey, "space-before-unit"))
+        {
+            options->sizeSpaceBeforeUnit = (FFSpaceBeforeUnitType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                {},
+            });
+        }
         else
             return false;
     }
@@ -439,6 +567,15 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             ffOptionParseColor(value, &options->tempColorYellow);
         else if(ffStrEqualsIgnCase(subkey, "color-red"))
             ffOptionParseColor(value, &options->tempColorRed);
+        else if(ffStrEqualsIgnCase(subkey, "space-before-unit"))
+        {
+            options->tempSpaceBeforeUnit = (FFSpaceBeforeUnitType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                {},
+            });
+        }
         else
             return false;
     }
@@ -455,9 +592,22 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             ffOptionParseColor(value, &options->percentColorYellow);
         else if(ffStrEqualsIgnCase(subkey, "color-red"))
             ffOptionParseColor(value, &options->percentColorRed);
+        else if(ffStrEqualsIgnCase(subkey, "space-before-unit"))
+        {
+            options->percentSpaceBeforeUnit = (FFSpaceBeforeUnitType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                {},
+            });
+        }
+        else if(ffStrEqualsIgnCase(subkey, "width"))
+            options->percentWidth = (uint8_t) ffOptionParseUInt32(key, value);
         else
             return false;
     }
+    else if(ffStrEqualsIgnCase(key, "--fraction-ndigits"))
+        options->fractionNdigits = (int8_t) ffOptionParseInt32(key, value);
     else if(ffStrEqualsIgnCase(key, "--no-buffer"))
         options->noBuffer = ffOptionParseBoolean(value);
     else if(ffStrStartsWithIgnCase(key, "--bar-"))
@@ -481,6 +631,15 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         const char* subkey = key + strlen("--freq-");
         if(ffStrEqualsIgnCase(subkey, "ndigits"))
             options->freqNdigits = (int8_t) ffOptionParseInt32(key, value);
+        else if(ffStrEqualsIgnCase(subkey, "space-before-unit"))
+        {
+            options->freqSpaceBeforeUnit = (FFSpaceBeforeUnitType) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "default", FF_SPACE_BEFORE_UNIT_DEFAULT },
+                { "always", FF_SPACE_BEFORE_UNIT_ALWAYS },
+                { "never", FF_SPACE_BEFORE_UNIT_NEVER },
+                {},
+            });
+        }
         else
             return false;
     }
@@ -505,12 +664,16 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     options->disableLinewrap = !options->pipe;
     #else
     options->disableLinewrap = false;
+    options->debugMode = false;
     #endif
 
+    options->durationSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
     options->hideCursor = false;
     options->sizeBinaryPrefix = FF_SIZE_BINARY_PREFIX_TYPE_IEC;
     options->sizeNdigits = 2;
     options->sizeMaxPrefix = UINT8_MAX;
+    options->sizeSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
+
     options->stat = -1;
     options->noBuffer = false;
     options->keyWidth = 0;
@@ -522,18 +685,26 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     ffStrbufInitStatic(&options->tempColorGreen, FF_COLOR_FG_GREEN);
     ffStrbufInitStatic(&options->tempColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
     ffStrbufInitStatic(&options->tempColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
+    options->tempSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
 
     ffStrbufInitStatic(&options->barCharElapsed, "■");
     ffStrbufInitStatic(&options->barCharTotal, "-");
     ffStrbufInitStatic(&options->barBorderLeft, "[ ");
     ffStrbufInitStatic(&options->barBorderRight, " ]");
     options->barWidth = 10;
+    options->durationAbbreviation = false;
+    options->durationSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
     options->percentType = 9;
     options->percentNdigits = 0;
     ffStrbufInitStatic(&options->percentColorGreen, FF_COLOR_FG_GREEN);
     ffStrbufInitStatic(&options->percentColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
     ffStrbufInitStatic(&options->percentColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
+    options->percentSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
+    options->percentWidth = 0;
+
     options->freqNdigits = 2;
+    options->freqSpaceBeforeUnit = FF_SPACE_BEFORE_UNIT_DEFAULT;
+    options->fractionNdigits = -1;
 
     ffListInit(&options->constants, sizeof(FFstrbuf));
 }
