@@ -16,9 +16,8 @@ typedef struct FFOptionsGeneral
     bool detectVersion;
 
     // Module options that cannot be put in module option structure
-    #if defined(__linux__) || defined(__FreeBSD__) || defined(__sun) || defined(__OpenBSD__) || defined(__NetBSD__)
+    #if defined(__linux__) || defined(__FreeBSD__) || defined(__sun) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__HAIKU__)
     FFstrbuf playerName;
-    bool escapeBedrock;
     FFDsForceDrmType dsForceDrm;
     #elif defined(_WIN32)
     int32_t wmiTimeout;
